/* paths */
/* We can't use absolute paths here, because those are dependent on Django's
STATIC_URL setting. However, django-compressor consistently places the compiled
CSS into ${STATIC_URL}/CACHE/css/ regardless of compilation mode, so we can
reliably use relative paths to get back to STATIC_URL. */
/* grid settings */
/* screen breakpoints */
/* 800px */
/* 900px */
/* 1200px */
/* 1600px */
/* colours */
/* darker to lighter */
/* misc sizing */
.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }
  .visuallyhidden:active, .visuallyhidden:focus {
    clip: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    position: static;
    width: auto; }

.visuallyvisible {
  clip: none;
  height: auto;
  width: auto;
  margin: auto;
  overflow: visible;
  position: initial; }

/* Utility variable - you should never need to modify this */
/* Ensure grid columns are set to border-boxes. This is essential */
/* Our row container */
/* Our column container */
/* Push adds left padding */
/* Pull adds right padding */
/* only used in places where padding not applied to same elements as row or row-flush
 * most of the time this class should be applied directly to the html elements */
h1 {
  font-weight: 300;
  font-size: 2.2em; }

header .col1 {
  width: 50px;
  margin-right: 1em;
  padding: 0; }
header h1, header h2 {
  color: white; }
header h2 {
  text-transform: none; }

.panel {
  margin-bottom: 4em; }

.summary {
  background-color: #fafafa;
  margin-bottom: 2em;
  padding-top: 2em;
  padding-bottom: 2em; }
  .summary:before, .summary:after {
    content: " ";
    display: table; }
  .summary:after {
    clear: both; }
  .summary ul.stats {
    width: 100%; }
    .summary ul.stats:before, .summary ul.stats:after {
      content: " ";
      display: table; }
    .summary ul.stats:after {
      clear: both; }
    .summary ul.stats, .summary ul.stats ul, .summary ul.stats li {
      list-style-type: none;
      font-style: normal; }
    .summary ul.stats, .summary ul.stats ul {
      margin-top: 0;
      margin-bottom: 0;
      padding-left: 0; }
    .summary ul.stats li {
      box-sizing: border-box;
      display: inline;
      float: left;
      width: 33.33333%;
      padding-right: 1.5%;
      padding-left: 1.5%; }
      .summary ul.stats li:before {
        opacity: 0.2;
        font-size: 6em;
        float: left; }
    .summary ul.stats a {
      position: relative;
      display: block;
      width: 100%;
      height: 100%; }
    .summary ul.stats span {
      font-family: Bitter, Georgia, serif;
      display: block;
      font-size: 4em;
      line-height: 1em;
      font-weight: 300; }
  .summary .search-bar {
    border-top: 1px solid #e6e6e6;
    padding: 1em 0 0 0; }
    .summary .search-bar:before, .summary .search-bar:after {
      content: " ";
      display: table; }
    .summary .search-bar:after {
      clear: both; }
    .summary .search-bar h2 {
      display: inline-block;
      margin-right: 1em; }
    .summary .search-bar .fields {
      display: inline-block;
      clear: none; }
    .summary .search-bar .field {
      display: inline-block; }
    .summary .search-bar label {
      display: inline-blo; }
    .summary .search-bar input {
      background-color: white; }
