/* paths */
/* We can't use absolute paths here, because those are dependent on Django's
STATIC_URL setting. However, django-compressor consistently places the compiled
CSS into ${STATIC_URL}/CACHE/css/ regardless of compilation mode, so we can
reliably use relative paths to get back to STATIC_URL. */
/* grid settings */
/* screen breakpoints */
/* 800px */
/* 900px */
/* 1200px */
/* 1600px */
/* colours */
/* darker to lighter */
/* misc sizing */
.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }
  .visuallyhidden:active, .visuallyhidden:focus {
    clip: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    position: static;
    width: auto; }

.visuallyvisible {
  clip: none;
  height: auto;
  width: auto;
  margin: auto;
  overflow: visible;
  position: initial; }

.focal-point-chooser {
  position: relative; }
  .focal-point-chooser .current-focal-point-indicator {
    box-shadow: 1px 1px 10px 0px black;
    position: absolute;
    border: 1px solid #43b1b0;
    opacity: 0.5; }
    body.ready .focal-point-chooser .current-focal-point-indicator {
      transition: opacity 0.2s ease; }
    .focal-point-chooser .current-focal-point-indicator .hidden {
      display: none; }
  .focal-point-chooser:hover .current-focal-point-indicator {
    opacity: 0; }
