/* paths */
/* We can't use absolute paths here, because those are dependent on Django's
STATIC_URL setting. However, django-compressor consistently places the compiled
CSS into ${STATIC_URL}/CACHE/css/ regardless of compilation mode, so we can
reliably use relative paths to get back to STATIC_URL. */
/* grid settings */
/* screen breakpoints */
/* 800px */
/* 900px */
/* 1200px */
/* 1600px */
/* colours */
/* darker to lighter */
/* misc sizing */
.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }
  .visuallyhidden:active, .visuallyhidden:focus {
    clip: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    position: static;
    width: auto; }

.visuallyvisible {
  clip: none;
  height: auto;
  width: auto;
  margin: auto;
  overflow: visible;
  position: initial; }

/* Utility variable - you should never need to modify this */
/* Ensure grid columns are set to border-boxes. This is essential */
/* Our row container */
/* Our column container */
/* Push adds left padding */
/* Pull adds right padding */
/* only used in places where padding not applied to same elements as row or row-flush
 * most of the time this class should be applied directly to the html elements */
.replace-file-input {
  display: inline-block;
  position: relative;
  overflow: hidden;
  padding-bottom: 2px; }
  .replace-file-input input[type=file] {
    padding: 0;
    opacity: 0;
    position: absolute;
    top: 0;
    right: 0;
    direction: ltr;
    width: auto;
    display: block;
    font-size: 5em; }
    .replace-file-input input[type=file]:hover {
      cursor: pointer; }
  .replace-file-input:hover {
    cursor: pointer; }
    .replace-file-input:hover button {
      background-color: #358c8b; }

.upload-list > li {
  padding: 1em; }
.upload-list .left {
  text-align: center; }
.upload-list .preview {
  width: 150px;
  min-height: 150px;
  display: block;
  position: relative;
  text-align: center;
  max-width: 100%;
  margin: auto; }
.upload-list .progress, .upload-list .thumb, .upload-list .thumb:before, .upload-list canvas, .upload-list img {
  position: absolute;
  max-width: 100%; }
.upload-list .progress {
  z-index: 4;
  top: 60%;
  left: 20%;
  right: 20%;
  width: 60%;
  box-shadow: 0 0 5px 2px rgba(255, 255, 255, 0.4); }
.upload-list .thumb {
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1;
  width: 100%; }
.upload-list .thumb:before, .upload-list canvas, .upload-list img {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  margin: auto; }
.upload-list .thumb:before {
  z-index: 2;
  top: 0;
  width: 1em;
  font-size: 10em;
  line-height: 1.4em;
  color: #f0f0f0; }
.upload-list canvas, .upload-list img {
  z-index: 3; }
.upload-list .hasthumb:before {
  display: none; }
.upload-list .status-msg {
  display: none; }
.upload-list .upload-complete .progress {
  opacity: 0; }
.upload-list .upload-success .status-msg.success {
  display: block; }
.upload-list .upload-failure {
  border-color: #cd3238; }
  .upload-list .upload-failure .preview {
    display: none; }
  .upload-list .upload-failure .status-msg.failure {
    display: block; }
