{% extends "wagtailadmin/block_forms/sequence_member.html" %}
{% block header_controls %}
    <div class="list-controls">
        <button type="button" id="{{ prefix }}-moveup" class="icon text-replace icon-order-up button-secondary button-nostroke">move up</button>
        <button type="button" id="{{ prefix }}-movedown" class="icon text-replace icon-order-down button-secondary button-nostroke">move down</button>
        <button type="button" id="{{ prefix }}-delete" class="icon text-replace no icon-bin button-secondary button-nostroke">delete</button>
    </div>
{% endblock %}
