{% load wagtailadmin_tags compress static %}

{% comment %}
    CSS declarations to be included on the 'create page' and 'edit page' views
{% endcomment %}

{% compress css %}
    <link rel="stylesheet" href="{% static 'wagtailadmin/css/layouts/page-editor.css' %}" type="text/css" />
    <link rel="stylesheet" href="{% static 'wagtailadmin/css/panels/rich-text.css' %}" type="text/css" />

    {# we'll want tag-it included, for the benefit of any modals that use it, like images. #}
    {# TODO: a method of injecting these sorts of things on demand when the modal is spawned #}
    <link rel="stylesheet" href="{% static 'wagtailadmin/css/vendor/jquery.tagit.css' %}">

    {% hook_output 'insert_editor_css' %}
{% endcompress %}

{{ edit_handler.form.media.css }}
