{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% blocktrans %}Delete {{ snippet_type_name}} - {{ instance }}{% endblocktrans %}{% endblock %}
{% block bodyclass %}menu-snippets{% endblock %}
{% block content %}
    {% trans "Delete" as delete_str %}
    {% include "wagtailadmin/shared/header.html" with title=delete_str subtitle=instance icon="snippet" %}

    <div class="nice-padding">
        <p>{% blocktrans %}Are you sure you want to delete this {{ snippet_type_name }}?{% endblocktrans %}</p>
        <form action="{% url 'wagtailsnippets_delete' content_type.app_label content_type.model instance.id %}" method="POST">
            {% csrf_token %}
            <input type="submit" value="{% trans 'Yes, delete' %}" class="serious" />
        </form>
    </div>
    
{% endblock %}
