{% load i18n %}
{% if page_types_restricted %}
    {% trans "Choose" as choose_str %}
    {% trans page_type.get_verbose_name as subtitle %}
{% else %}
    {% trans "Choose a page" as choose_str %}
{% endif %}

{% include "wagtailadmin/shared/header.html" with title=choose_str subtitle=subtitle search_url="wagtailadmin_choose_page" query_parameters="page_type="|add:page_type_string icon="doc-empty-inverse" %}

<div class="nice-padding">
    {% include 'wagtailadmin/chooser/_link_types.html' with current='internal' %}

    <div class="page-results">
        {% include 'wagtailadmin/chooser/_browse_results.html' %}
    </div>
</div>
