.progress{
    @include border-radius(1.2em);
    background-color:$color-teal-dark;
    border:1px solid $color-teal;
    opacity:0;

    &.active{
        opacity:1;
        @include transition(opacity 0.3s ease);
    } 

    .bar{
        @include border-radius(1.5em);
        @include transition(width 0.3s ease);
        overflow:hidden;
        box-sizing:border-box;
        text-align:right;
        line-height:1.2em;
        color:white;
        font-size:0.85em;
        background-color:$color-teal;
        height:1.2em;
        padding-right:1em;
    }
}