{% load i18n %}

<p class="help-block help-warning">
    {% blocktrans with type=page_type_name %}
        Only pages of type "{{ type }}" may be chosen for this field. Search results will exclude pages of other types.
    {% endblocktrans %}
</p>
