/* paths */
/* We can't use absolute paths here, because those are dependent on Django's
STATIC_URL setting. However, django-compressor consistently places the compiled
CSS into ${STATIC_URL}/CACHE/css/ regardless of compilation mode, so we can
reliably use relative paths to get back to STATIC_URL. */
/* grid settings */
/* screen breakpoints */
/* 800px */
/* 900px */
/* 1200px */
/* 1600px */
/* colours */
/* darker to lighter */
/* misc sizing */
.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }
  .visuallyhidden:active, .visuallyhidden:focus {
    clip: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    position: static;
    width: auto; }

.visuallyvisible {
  clip: none;
  height: auto;
  width: auto;
  margin: auto;
  overflow: visible;
  position: initial; }

.icon.teal {
  color: #43b1b0; }

.icon.white {
  color: white; }

.icon:before, .icon:after, .hallotoolbar [class^="icon-"], .hallotoolbar [class*=" icon-"]:before, .hallotoolbar [class^="icon-"]:before {
  font-family: "wagtail";
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none !important;
  speak: none;
  text-decoration: none;
  width: 1.3em;
  line-height: 1em;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-align: left;
  vertical-align: middle;
  margin-right: 0.2em; }

.icon:after, .hallotoolbar [class^="icon-"]:after, .hallotoolbar [class^="icon-"]:after {
  text-align: right; }

.hallotoolbar [class^="icon-"], .hallotoolbar [class*=" icon-"]:before, .hallotoolbar [class*=" icon-"]:before, .hallotoolbar [class^="icon-"]:before {
  vertical-align: -10%;
  margin-right: 0; }

.icon-cogs:before {
  content: "a"; }

.icon-doc-empty-inverse:before {
  content: "b"; }

.icon-doc-empty:before {
  content: "c"; }

.icon-edit:before {
  content: "d"; }

.icon-arrow-up:before, .icon-arrow-up-after:after {
  content: "e"; }

.icon-arrow-down:before, .icon-arrow-down-after:after {
  content: "q"; }

.icon-search:before {
  content: "f"; }

.icon-cross:before {
  content: "g"; }

.icon-folder-open-1:before {
  content: "i"; }

.icon-folder-inverse:before {
  content: "j"; }

.icon-mail:before {
  content: "k"; }

.icon-arrows-up-down:before {
  content: "l"; }

.icon-locked:before {
  content: "m"; }

.icon-arrow-right:before, .icon-arrow-right-after:after {
  content: "n"; }

.icon-doc-full:before, .icon-file-text-alt:before {
  content: "h"; }

.icon-image:before, .icon-picture:before {
  content: "o"; }

.icon-unlocked:before {
  content: "p"; }

.icon-doc-full-inverse:before {
  content: "r"; }

.icon-folder:before {
  content: "s"; }

.icon-plus:before {
  content: "t"; }

.icon-tag:before {
  content: "u"; }

.icon-folder-open-inverse:before {
  content: "v"; }

.icon-cog:before {
  content: "w"; }

.icon-tick:before {
  content: "x"; }

.icon-user:before {
  content: "y"; }

.icon-arrow-left:before {
  content: "z"; }

.icon-tick-inverse:before {
  content: "A"; }

.icon-plus-inverse:before {
  content: "B"; }

.icon-snippet:before {
  content: "D"; }

.icon-wagtail:before {
  content: "V"; }

.icon-wagtail-inverse:before {
  content: "0"; }

.icon-bold:before {
  content: "C"; }

.icon-italic:before {
  content: "E"; }

.icon-undo:before {
  content: "H"; }

.icon-repeat:before {
  content: "I"; }

.icon-list-ol:before {
  content: "G"; }

.icon-list-ul:before {
  content: "F"; }

.icon-link:before {
  content: "J"; }

.icon-radio-full:before {
  content: "K"; }

.icon-radio-empty:before {
  content: "L"; }

.icon-arrow-up-big:before {
  content: "M"; }

.icon-arrow-down-big:before {
  content: "N"; }

.icon-group:before {
  content: "O"; }

.icon-media:before {
  content: "P"; }

.icon-horizontalrule:before {
  font-family: Open Sans, Arial, sans-serif !important;
  content: "\2014"; }

.icon-password:before {
  content: "Q"; }

.icon-download:before {
  content: "S";
  /* Credit: Icon made by Freepik from Flaticon.com */ }

.icon-order:before {
  content: "T"; }

.icon-grip:before {
  content: "U"; }

.icon-home:before {
  content: "W"; }

.icon-order-down:before {
  content: "X"; }

.icon-order-up:before {
  content: "Y"; }

.icon-bin:before {
  content: "Z"; }

.icon-spinner:after {
  width: 1em;
  animation: spin 0.5s infinite linear;
  -webkit-animation: spin 0.5s infinite linear;
  -moz-animation: spin 0.5s infinite linear;
  content: "1"; }

.icon-pick:before {
  content: "2"; }

.icon-redirect:before {
  content: "3"; }

.icon-view:before, .icon-no-view:before {
  vertical-align: -3.5px;
  font-size: 1.1rem; }

.icon-view:before {
  content: "4"; }

.icon-no-view:before {
  content: "^"; }

.icon-collapse-down:before {
  content: "5"; }

.icon-collapse-up:before {
  content: "6"; }

.icon-date:before {
  content: "7"; }

.icon-time:before {
  content: "8"; }

.icon-success:before {
  content: "9"; }

.icon-help:before {
  content: "?"; }

.icon-warning:before {
  content: "!"; }

.icon-form:before {
  content: "$"; }

.icon-site:before {
  content: "@"; }

.icon-placeholder:before {
  content: "{"; }

.icon-pilcrow:before {
  content: "\e600"; }

.icon-title:before {
  content: "\f034"; }

.icon-code:before {
  content: "\e601"; }

.icon-openquote:before {
  content: "“"; }

.icon-larger:before {
  font-size: 1.5em; }

.icon.text-replace {
  font-size: 0em;
  line-height: 0;
  overflow: hidden; }
  .icon.text-replace:before {
    margin-right: 0;
    font-size: 1rem;
    display: inline-block;
    width: 100%;
    line-height: 1.2em;
    text-align: center;
    vertical-align: middle; }

@keyframes spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@-webkit-keyframes spin {
  from {
    -webkit-transform: rotate(0deg); }

  to {
    -webkit-transform: rotate(360deg); } }

@font-face {
  font-family: "Open Sans";
  src: url("../../wagtailadmin/fonts/OpenSans-Light-webfont.eot");
  src: url("../../wagtailadmin/fonts/OpenSans-Light-webfont.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/OpenSans-Light-webfont.ttf") format("truetype"), url("../../wagtailadmin/fonts/OpenSans-Light-webfont.svg#opensans_italic_webfont") format("svg"), url("../../wagtailadmin/fonts/OpenSans-Light-webfont.woff") format("woff");
  font-weight: 300;
  font-style: normal; }

@font-face {
  font-family: "Open Sans";
  src: url("../../wagtailadmin/fonts/OpenSans-Regular-webfont.eot");
  src: url("../../wagtailadmin/fonts/OpenSans-Regular-webfont.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/OpenSans-Regular-webfont.ttf") format("truetype"), url("../../wagtailadmin/fonts/OpenSans-Regular-webfont.svg#opensans_regular_webfont") format("svg"), url("../../wagtailadmin/fonts/OpenSans-Regular-webfont.woff") format("woff");
  font-weight: 400;
  font-style: normal; }

@font-face {
  font-family: "Open Sans";
  src: url("../../wagtailadmin/fonts/OpenSans-Semibold-webfont.eot");
  src: url("../../wagtailadmin/fonts/OpenSans-Semibold-webfont.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/OpenSans-Semibold-webfont.ttf") format("truetype"), url("../../wagtailadmin/fonts/OpenSans-Semibold-webfont.svg#opensans_semibold_webfont") format("svg"), url("../../wagtailadmin/fonts/OpenSans-Semibold-webfont.woff") format("woff");
  font-weight: 600;
  font-style: normal; }

@font-face {
  font-family: "Open Sans";
  src: url("../../wagtailadmin/fonts/OpenSans-Bold-webfont.eot");
  src: url("../../wagtailadmin/fonts/OpenSans-Bold-webfont.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/OpenSans-Bold-webfont.ttf") format("truetype"), url("../../wagtailadmin/fonts/OpenSans-Bold-webfont.svg#opensans_bold_webfont") format("svg"), url("../../wagtailadmin/fonts/OpenSans-Bold-webfont.woff") format("woff");
  font-weight: 700;
  font-style: normal; }

@font-face {
  font-family: "Bitter";
  src: url("../../wagtailadmin/fonts/Bitter-Regular.eot");
  src: url("../../wagtailadmin/fonts/Bitter-Regular.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/Bitter-Regular.ttf") format("truetype"), url("../../wagtailadmin/fonts/Bitter-Regular.svg#Bitter-Regular") format("svg"), url("../../wagtailadmin/fonts/Bitter-Regular.woff") format("woff");
  font-weight: 400;
  font-style: normal; }

@font-face {
  font-family: "Bitter";
  src: url("../../wagtailadmin/fonts/Bitter-Bold.eot");
  src: url("../../wagtailadmin/fonts/Bitter-Bold.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/Bitter-Bold.ttf") format("truetype"), url("../../wagtailadmin/fonts/Bitter-Bold.svg#Bitter-Bold") format("svg"), url("../../wagtailadmin/fonts/Bitter-Bold.woff") format("woff");
  font-weight: 700;
  font-style: normal; }

@font-face {
  font-family: "wagtail";
  src: url("../../wagtailadmin/fonts/wagtail.eot");
  src: url("../../wagtailadmin/fonts/wagtail.eot?#iefix") format("embedded-opentype"), url("../../wagtailadmin/fonts/wagtail.ttf") format("truetype"), url("../../wagtailadmin/fonts/wagtail.svg#wagtail") format("svg"), url("../../wagtailadmin/fonts/wagtail.woff") format("woff");
  font-weight: normal;
  font-style: normal; }

/* fix to make chrome on windows use svg, which renders better */
@media screen and (-webkit-min-device-pixel-ratio: 0) {
  @font-face {
    font-family: "wagtail";
    src: url("../../wagtailadmin/fonts/wagtail.svg#wagtail") format("svg"); }
 }

html, body {
  background-color: transparent; }

body {
  -webkit-font-smoothing: antialiased;
  /* Do not remove! */
  font-family: Open Sans, Arial, sans-serif;
  font-size: 80%; }

nav {
  padding: 0 0 3em 3em;
  float: right;
  /* moving menu only for browser that can support hover and transitions */ }
  .no-touch .ready nav ul {
    height: 0; }
  .no-touch .ready nav li {
    left: 50px; }
  .no-touch .ready nav:hover ul {
    height: 300px; }
  .no-touch .ready nav:hover li {
    left: 0; }

.home {
  width: 3.5em;
  height: 3.5em;
  margin-bottom: 1px;
  background-color: white;
  color: #666666;
  padding: 0; }
  .home.icon:before {
    font-size: 35px;
    margin: 0.2em 0.15em;
    display: block; }
    body.ready .home.icon:before {
      transition: color 0.2s ease; }
  .home:hover:before {
    color: black; }

ul {
  overflow: hidden;
  clear: both; }
  body.ready ul {
    transition: height 0.2s ease; }
  ul, ul ul, ul li {
    list-style-type: none;
    font-style: normal; }
  ul, ul ul {
    margin-top: 0;
    margin-bottom: 0;
    padding-left: 0; }

li {
  float: right;
  clear: both;
  width: 3.5em;
  overflow: hidden;
  position: relative;
  padding-bottom: 1px; }
  body.ready li {
    transition: left 0.2s ease, width 0.1s ease; }
  li:hover {
    width: 10em; }

/* all items or pseudo-items must float right */
li, .home {
  float: right; }

.action {
  background-color: #43b1b0;
  color: #43b1b0; }
  body.ready .action {
    transition: background-color 0.2s ease, color 0.2s ease; }
  .action:before {
    margin-right: 0.4em;
    vertical-align: middle;
    font-size: 1.7em;
    color: white; }
  .action:hover {
    background-color: #246060;
    color: white; }

/* actions which can be accomplished just with a link tag */
a.action, a {
  display: block;
  width: 10em;
  text-align: left;
  overflow: hidden;
  text-decoration: none;
  text-transform: uppercase;
  padding: 0.85em 1em; }

/* actions which require wrapping a form input */
div.action input {
  color: white;
  -webkit-font-smoothing: antialiased;
  /* Do not remove! */
  font-family: Open Sans, Arial, sans-serif;
  border: 0;
  background: none;
  display: block;
  text-transform: uppercase;
  padding: 1em;
  width: 10em;
  position: relative;
  z-index: 1;
  text-align: left;
  padding-left: 3.5em; }
div.action:before {
  position: absolute;
  top: 0.4em;
  left: 0.5em;
  z-index: 0; }
