{% extends "wagtailadmin/block_forms/sequence_member.html" %}

{% block hidden_fields %}
    <input type="hidden" id="{{ prefix }}-type" name="{{ prefix }}-type" value="{{ child.block.name }}">
{% endblock %}

{% block header_controls %}
    <div class="stream-controls">
        <button type="button" id="{{ prefix }}-moveup" class="icon text-replace icon-order-up button-secondary button-nostroke">move up</button>
        <button type="button" id="{{ prefix }}-movedown" class="icon text-replace icon-order-down button-secondary button-nostroke">move down</button>
        <button type="button" id="{{ prefix }}-delete" class="stream-control icon text-replace no icon-bin button-secondary button-nostroke">delete</button>
    </div>
{% endblock %}

{% block footer_controls %}
    {% include "wagtailadmin/block_forms/stream_menu.html" with menu_id=prefix|add:"-appendmenu" state="closed" %}
{% endblock %}
