{% extends "wagtailadmin/base.html" %}
{% load i18n %}

{% block titletag %}{% trans "Add site" %} {{ site.hostname }}{% endblock %}
{% block bodyclass %}menu-sites{% endblock %}

{% block content %}

    {% trans "Add site" as add_site_str %}
    {% include "wagtailadmin/shared/header.html" with title=add_site_str icon="site" %}

    <form action="{% url 'wagtailsites_create' %}" method="POST">
        {% csrf_token %}
        <div class="nice-padding">
            <ul class="fields">
                {% include "wagtailadmin/shared/field_as_li.html" with field=form.hostname %}
                {% include "wagtailadmin/shared/field_as_li.html" with field=form.port %}
                {% include "wagtailadmin/shared/field_as_li.html" with field=form.root_page %}
                {% include "wagtailadmin/shared/field_as_li.html" with field=form.is_default_site %}
               
                <li><input type="submit" value="{% trans 'Save' %}" /></li>
            </ul>
        </div>
    </form>
{% endblock %}
{% block extra_js %}
    {% include "wagtailadmin/pages/_editor_js.html" %}
{% endblock %}
