{% extends "wagtailadmin/userbar/item_base.html" %}
{% load i18n %}

{% block item_content %}
    <a href="{% url 'wagtailadmin_pages_edit' self.page.id %}" target="_parent" class="action icon icon-edit">{% trans 'Edit' %}</a>
{% endblock %}