{% load i18n %}

{% if page_types_restricted %}
    {% include "wagtailadmin/chooser/_page_type_restricted_warning.html" with page_type_name=page_type.get_verbose_name %}
{% endif %}

<h2>
    {% blocktrans count counter=pages|length %}
        There is one match
    {% plural %}
        There are {{ counter }} matches
    {% endblocktrans %}
</h2>

{% if pages %}
    {% include "wagtailadmin/pages/list.html" with choosing=1 show_parent=1 pages=pages parent_page=parent_page %}
{% endif %}
