@font-face {
    font-family: "Open Sans";
    src:url("#{$font-root}OpenSans-Light-webfont.eot");
    src:url("#{$font-root}OpenSans-Light-webfont.eot?#iefix") format("embedded-opentype"),
        url("#{$font-root}OpenSans-Light-webfont.ttf") format("truetype"),
        url("#{$font-root}OpenSans-Light-webfont.svg#opensans_italic_webfont") format("svg"),
        url("#{$font-root}OpenSans-Light-webfont.woff") format("woff");
    font-weight: 300;
    font-style: normal;
}

@font-face {
    font-family: "Open Sans";
    src:url("#{$font-root}OpenSans-Regular-webfont.eot");
    src:url("#{$font-root}OpenSans-Regular-webfont.eot?#iefix") format("embedded-opentype"),
        url("#{$font-root}OpenSans-Regular-webfont.ttf") format("truetype"),
        url("#{$font-root}OpenSans-Regular-webfont.svg#opensans_regular_webfont") format("svg"),
        url("#{$font-root}OpenSans-Regular-webfont.woff") format("woff");
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: "Open Sans";
    src:url("#{$font-root}OpenSans-Semibold-webfont.eot");
    src:url("#{$font-root}OpenSans-Semibold-webfont.eot?#iefix") format("embedded-opentype"),
        url("#{$font-root}OpenSans-Semibold-webfont.ttf") format("truetype"),
        url("#{$font-root}OpenSans-Semibold-webfont.svg#opensans_semibold_webfont") format("svg"),
        url("#{$font-root}OpenSans-Semibold-webfont.woff") format("woff");
    font-weight: 600;
    font-style: normal;
}

@font-face {
    font-family: "Open Sans";
    src:url("#{$font-root}OpenSans-Bold-webfont.eot");
    src:url("#{$font-root}OpenSans-Bold-webfont.eot?#iefix") format("embedded-opentype"),
        url("#{$font-root}OpenSans-Bold-webfont.ttf") format("truetype"),
        url("#{$font-root}OpenSans-Bold-webfont.svg#opensans_bold_webfont") format("svg"),
        url("#{$font-root}OpenSans-Bold-webfont.woff") format("woff");
    font-weight: 700;
    font-style: normal;
}

@font-face {
    font-family: "Bitter";
    src: url("#{$font-root}Bitter-Regular.eot");
    src: url("#{$font-root}Bitter-Regular.eot?#iefix") format("embedded-opentype"),
       url("#{$font-root}Bitter-Regular.ttf") format("truetype"),
       url("#{$font-root}Bitter-Regular.svg#Bitter-Regular") format("svg"),
       url("#{$font-root}Bitter-Regular.woff") format("woff");
    font-weight:400;
    font-style:normal;
}

@font-face {
    font-family: "Bitter";
    src: url("#{$font-root}Bitter-Bold.eot");
    src: url("#{$font-root}Bitter-Bold.eot?#iefix") format("embedded-opentype"),
       url("#{$font-root}Bitter-Bold.ttf") format("truetype"),
       url("#{$font-root}Bitter-Bold.svg#Bitter-Bold") format("svg"),
       url("#{$font-root}Bitter-Bold.woff") format("woff");
    font-weight:700;
    font-style:normal;
}

@font-face {
    font-family: "wagtail";
    src:url("#{$font-root}wagtail.eot");
    src:url("#{$font-root}wagtail.eot?#iefix") format("embedded-opentype"),
        url("#{$font-root}wagtail.ttf") format("truetype"),
        url("#{$font-root}wagtail.svg#wagtail") format("svg"),
        url("#{$font-root}wagtail.woff") format("woff");
    font-weight: normal;
    font-style: normal;
}
/* fix to make chrome on windows use svg, which renders better */
@media screen and (-webkit-min-device-pixel-ratio:0) {
    @font-face {
        font-family: "wagtail";
        src: url("#{$font-root}wagtail.svg#wagtail") format("svg");
    }
}
